@@ -4,9 +4,10 @@ import re
 
 import numpy as np
 import pandas as pd
-import wgdi
 from Bio import Seq, SeqIO, SeqRecord
 
+import wgdi
+
 
 def config():
     conf = configparser.ConfigParser()
@@ -28,7 +29,8 @@ def rewrite(file, section):
             if k == section:
                 continue
             conf.remove_section(k)
-        conf.write(open(os.path.join(wgdi.__path__[0], 'example/conf.ini'), 'w'))
+        conf.write(
+            open(os.path.join(wgdi.__path__[0], 'example/conf.ini'), 'w'))
         print('Option ini has been modified')
     else:
         print('Option ini no change')
@@ -81,6 +83,25 @@ def read_mcscanx(fn):
     return data
 
 
+def read_jcvi(fn):
+    f1 = open(fn)
+    data, b = [], []
+    num = 1
+    for line in f1.readlines():
+        line = line.strip()
+        if re.match(r"###", line):
+            if len(b) == 0:
+                continue
+            data.append([num, b, 0])
+            b = []
+            num += 1
+            continue
+        a = re.split(r"\t", line)
+        b.append([a[0], a[0], a[1], a[1]])
+    data.append([num, b, 0])
+    return data
+
+
 def read_coliearity(fn):
     f1 = open(fn)
     data, b = [], []
@@ -164,6 +185,16 @@ def newlens(file, position):
     return lens
 
 
+def read_calassfication(file):
+    classification = pd.read_csv(file, sep="\t", header=None)
+    classification[0] = classification[0].astype(str)
+    classification[1] = classification[1].astype(int)
+    classification[2] = classification[2].astype(int)
+    classification[3] = classification[3].astype(str)
+    classification[4] = classification[4].astype(int)
+    return classification
+
+
 def gene_location(gff, lens, step, position):
     loc_gene, dict_chr, n = {}, {}, 0
     gff = gff[gff['chr'].isin(lens.index)].copy()
